##
##  k6.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2018 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_opkg     0.20.0
%define       V_dist     0.20.0-dev-dccb254863d4810cf53d5f79408c38955920d4d0

#   package information
Name:         k6
Summary:      HTTP/HTTPS/WebSocket Load Generator
URL:          https://k6.io/
Vendor:       Load Impact
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      AGPL
Version:      %{V_opkg}
Release:      20180430

#   list of sources
Source0:      https://github.com/loadimpact/k6/archive/v%{V_dist}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    k6 is a modern load testing tool. Its features are: Scripting in
    ES6 JS: support for modules to aid code reusability across an
    organization; Everything as code: test logic and configuration
    options are both in JS for version control friendliness;
    Automation-friendly: checks (like asserts) and thresholds; HTTP/1.1,
    HTTP/2 and WebSocket protocol support; TLS features: client
    certificates, configurable SSL/TLS versions and ciphers; Batteries
    included: Cookies, Crypto, Custom metrics, Encodings, Environment
    variables, JSON, HTML forms and more; and Flexible metrics
    storage/visualization: InfluxDB (+Grafana), JSON or Load Impact
    Insights.

%track
    prog k6 = {
        version   = %{V_dist}
        url       = https://github.com/loadimpact/k6/releases
        regex     = k6-v(\d+\.\d+\.\d+-dev-[0-9a-f]+)\.tar\.gz
    }

%prep
    %setup -q -n k6-%{V_dist}

%build
    #   build program
    (   export GOPATH=`pwd`
        mkdir -p $GOPATH/src/github.com/loadimpact
        ln -s ../../.. $GOPATH/src/github.com/loadimpact/k6
        go build -x -o k6 main.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        k6 $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

